@@ -1165,6 +1165,7 @@ Ext.app.App = Ext.extend(Ext.util.Observable, {
                     return true;
                 }
             });
+            this.checkHeights();
         }
     },
 
@@ -1186,7 +1187,10 @@ Ext.app.App = Ext.extend(Ext.util.Observable, {
                 failure: function(){
                     uiAjaxFailMessage.apply(this, arguments);
                 },
-                scope: this
+                scope: this,
+                success: function () {
+                    this.checkHeights();
+                },
             });
         }
     },
@@ -1210,6 +1214,63 @@ Ext.app.App = Ext.extend(Ext.util.Observable, {
         return {}
     },
 
+    checkHeights: function () {
+        // Изменяет размер иконок в зависимости от количества текста
+
+        function addNewHover(cellHeight) {
+            // Изменяет размер картинки заднего плана (block:hover)
+            let head = document.getElementsByTagName('head')[0];
+            let style = document.createElement('style');
+            let declarations = document.createTextNode(
+                `#x-shortcuts td a .block:hover{
+                background:url( ../${params.desktopItemBackgroundUrl} ) no-repeat 0 -${cellHeight}px;
+                background-size: 100% 200%;
+            }`);
+            style.type = 'text/css';
+
+            if (style.styleSheet) {
+              style.styleSheet.cssText = declarations.nodeValue;
+            } else {
+              style.appendChild(declarations);
+            }
+
+            head.appendChild(style);
+        }
+
+        let blocks = Ext.select('.block', true),
+            blockElements = blocks.elements,
+            textHeight = 0;
+        if (blockElements.length === 0) return;
+
+        let cellHeight = blocks.last().getHeight();
+
+        const baseTextHeight = 134,
+              step = 15;
+
+        for (let i = 0; i < blockElements.length; i++) {
+            textHeight = Math.max(textHeight, blockElements[i].query('.text')[0].clientHeight);
+            if (textHeight >= cellHeight) {
+                while (cellHeight <= textHeight) {
+                    cellHeight += step;
+                }
+            } else if (baseTextHeight >= textHeight) {
+                while (cellHeight > baseTextHeight && cellHeight > 149) {
+                    cellHeight -= step;
+                }
+            }
+        }
+
+        Ext.each(blockElements, function (block) {
+            block.setStyle({
+                'background-size': '100% 200%',
+            })
+            block.select('.base-desktop-image').item(0).setStyle({
+                'height': `${cellHeight}px`
+            })
+        });
+        addNewHover(cellHeight);
+    },
+
     removeDesktopItem: function(id){
         var el = Ext.get(id),
             cmp = getDesktopComponent(el);
@@ -1225,7 +1286,10 @@ Ext.app.App = Ext.extend(Ext.util.Observable, {
                 failure: function(){
                     uiAjaxFailMessage.apply(this, arguments);
                 },
-                scope: this
+                scope: this,
+                success: function () {
+                    this.checkHeights();
+                },
             });
         }
     },
