@@ -80,6 +80,11 @@ Ext.m3.AdvancedDataField = Ext.extend(Ext.form.DateField, {
                 var today = new Date();
                 this.setValue(today);
                 this.fireEvent('select', this, today);
+				// Добавлен ивент для разделения логики работы кнопки выбора текущей даты,
+				// т.к. выбор из календаря вызывает select -> change, ввод с клавиатуры вызывает change,
+				// а установка текущей даты select. Из чего нельзя найти такой способ, в котором были бы
+				// обработаны все 3 ситуации без двойного срабатывания при выборе из календаря.
+				this.fireEvent('setToday', this, today);
             }
 		};
 		this.baseTriggers[1].hide = this.hideTriggerToday;
