@@ -1119,11 +1119,10 @@ Ext.m3.MultiGroupingGridPanel = Ext.extend(Ext.ux.grid.livegrid.GridPanel, {
             * на редактирование передается одна запись, которая была
             * изначально загружена в грид быстрого просмотра
              */
-			var baseConf = this.getMainContext();
+			var baseConf = this.getSelectionContext(this.localEdit);
             var sm = this.getSelectionModel();
             var idField = this.getStore().idProperty;
-            var record;
-				record = sm.getSelected();
+            var record = sm.getSelected();
 				baseConf[this.rowIdName] = record.json[idField];
 			var mask = new Ext.LoadMask(this.body);
             var disableState = this.getToolbarsState();
