@@ -782,4 +782,36 @@ Ext.override(Ext.Button, {
             }
         }
     }
-});
\ No newline at end of file
+});
+
+
+Ext.override(Ext.m3.AdvancedDataField, {
+    onBlur : function(){
+	/*
+	   В суперклассе Ext.form.TriggerField данный метод перекрывается пустой функцией,
+   	   видимо для того, чтобы все изменения и событие change происходили только при нажатии на триггеры,
+ 	   но данное поведение весьма неудобно в колоночных фильтрах, где требуется корректное срабатывание
+       blur и change при потере фокуса. Также есть проверка для прерывания дальнейших неправильных вызовов.
+	   Данная реализация метода взята из базового класса Ext.formField
+	*/
+        if (this.value == this.getRawValue()) {
+            return;
+        }
+
+	    this.beforeBlur();
+	    if(this.focusClass){
+	        this.el.removeClass(this.focusClass);
+	    }
+	    this.hasFocus = false;
+	    if(this.validationEvent !== false && (this.validateOnBlur || this.validationEvent == 'blur')){
+	        this.validate();
+	    }
+	    var v = this.getValue();
+	    if(String(v) !== String(this.startValue)){
+	        this.fireEvent('change', this, v, this.startValue);
+	    }
+	    this.fireEvent('blur', this);
+	    this.postBlur();
+    }
+
+});
