@@ -1,9 +1,9 @@
-#coding:utf-8
+# coding: utf-8
+from __future__ import absolute_import
 
 from uuid import uuid4
 
-from django.template import Context
-from django.template.loader import get_template
+from m3_django_compat import get_template
 
 
 def render_component(component):
@@ -12,9 +12,8 @@ def render_component(component):
     :type component: BaseExtComponent или наследник
     :rtype: str
     """
-    context = Context({'component': component, 'self': component})
     template = get_template(component.template)
-    return template.render(context)
+    return template.render({'component': component, 'self': component})
 
 
 def render_template(template_name, variables=None):
@@ -25,19 +24,21 @@ def render_template(template_name, variables=None):
     :type variables: dict
     :rtype: str
     """
-    context = Context(variables or {})
     template = get_template(template_name)
-    return template.render(context)
+    return template.render(variables or {})
 
 
-def normalize(str):
+def normalize(s):
     """
     Конвертирует строку в вид, понятный javascript'у
-    :param str: строка
-    :type str: str
+    :param str s: строка
     :rtype: str
     """
-    return str.replace(
+    return s.replace(
+        '\\', '\\\\'
+    ).replace(
+        '\t', '\\t'
+    ).replace(
         '\r', '\\r'
     ).replace(
         '\n', '\\n'
@@ -69,8 +70,8 @@ def get_img_size(src_size, dest_size):
     width, height = dest_size
     src_width, src_height = src_size
     if height >= width:
-        return (int(float(width) / height * src_height), src_height)
-    return (src_width, int(float(height) / width * src_width))
+        return (int(float(width) // height * src_height), src_height)
+    return (src_width, int(float(height) // width * src_width))
 
 
 def generate_id():
