@@ -231,11 +231,17 @@ class ExtDictSelectField(BaseExtTriggerField):
         attr_set = set(self.fields)
         attr_set.add(self.value_field)
         attr_set.add(self.display_field)
-        self.__record_value = {}
+        self.set_empty_record_value()
         for attr in attr_set:
             value = getattr(obj, attr, None)
             self.__record_value[attr] = value() if callable(value) else value
 
+    def set_empty_record_value(self):
+        """
+        Установка пустого record_value.
+        """
+        self.__record_value = {}
+
     @property
     def pack(self):
         return self._pack
